@@ -13,11 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#define UNSTABLE_POPPLER_QT4
-
 #include "poppler-qt4.h"
 #include "poppler-private.h"
 
@@ -30,12 +28,17 @@ TextBox::TextBox(const QString& text, const QRectF &bBox)
 	m_data->bBox = bBox;
 }
 
-const QString &TextBox::text() const
+TextBox::~TextBox()
+{
+	delete m_data;
+}
+
+QString TextBox::text() const
 {
 	return m_data->text;
 }
 
-const QRectF &TextBox::boundingBox() const
+QRectF TextBox::boundingBox() const
 {
 	return m_data->bBox;
 };
